# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr, field_validator
from pydantic import Field
from sailpoint.beta.models.recommendation_request import RecommendationRequest
from sailpoint.beta.models.recommender_calculations import RecommenderCalculations
from sailpoint.beta.models.translation_message import TranslationMessage
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class RecommendationResponse(BaseModel):
    """
    RecommendationResponse
    """ # noqa: E501
    request: Optional[RecommendationRequest] = None
    recommendation: Optional[StrictStr] = Field(default=None, description="The recommendation - YES if the access is recommended, NO if not recommended, MAYBE if there is not enough information to make a recommendation, NOT_FOUND if the identity is not found in the system")
    interpretations: Optional[List[StrictStr]] = Field(default=None, description="The list of interpretations explaining the recommendation. The array is empty if includeInterpretations is false or not present in the request. e.g. - [ \"Not approved in the last 6 months.\" ]. Interpretations will be translated using the client's locale as found in the Accept-Language header. If a translation for the client's locale cannot be found, the US English translation will be returned.")
    translation_messages: Optional[List[TranslationMessage]] = Field(default=None, description="The list of translation messages, if they have been requested.", alias="translationMessages")
    recommender_calculations: Optional[RecommenderCalculations] = Field(default=None, alias="recommenderCalculations")
    __properties: ClassVar[List[str]] = ["request", "recommendation", "interpretations", "translationMessages", "recommenderCalculations"]

    @field_validator('recommendation')
    def recommendation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('true', 'false', 'MAYBE', 'NOT_FOUND'):
            raise ValueError("must be one of enum values ('true', 'false', 'MAYBE', 'NOT_FOUND')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RecommendationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of request
        if self.request:
            _dict['request'] = self.request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in translation_messages (list)
        _items = []
        if self.translation_messages:
            for _item in self.translation_messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['translationMessages'] = _items
        # override the default output from pydantic by calling `to_dict()` of recommender_calculations
        if self.recommender_calculations:
            _dict['recommenderCalculations'] = self.recommender_calculations.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RecommendationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "request": RecommendationRequest.from_dict(obj.get("request")) if obj.get("request") is not None else None,
            "recommendation": obj.get("recommendation"),
            "interpretations": obj.get("interpretations"),
            "translationMessages": [TranslationMessage.from_dict(_item) for _item in obj.get("translationMessages")] if obj.get("translationMessages") is not None else None,
            "recommenderCalculations": RecommenderCalculations.from_dict(obj.get("recommenderCalculations")) if obj.get("recommenderCalculations") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.branding_api import BrandingApi


class TestBrandingApi(unittest.TestCase):
    """BrandingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BrandingApi()

    def tearDown(self) -> None:
        pass

    def test_create_branding_item(self) -> None:
        """Test case for create_branding_item

        Create a branding item
        """
        pass

    def test_delete_branding(self) -> None:
        """Test case for delete_branding

        Delete a branding item
        """
        pass

    def test_get_branding(self) -> None:
        """Test case for get_branding

        Get a branding item
        """
        pass

    def test_get_branding_list(self) -> None:
        """Test case for get_branding_list

        List of branding items
        """
        pass

    def test_set_branding_item(self) -> None:
        """Test case for set_branding_item

        Update a branding item
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from sailpoint.beta.models.task_status import TaskStatus

class TestTaskStatus(unittest.TestCase):
    """TaskStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TaskStatus:
        """Test TaskStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TaskStatus`
        """
        model = TaskStatus()
        if include_optional:
            return TaskStatus(
                id = 'id12345',
                type = 'QUARTZ',
                unique_name = 'Big Task',
                description = 'A Really Big Task',
                parent_name = 'Parent Task',
                launcher = 'sweep',
                target = sailpoint.beta.models.target.Target(
                    id = 'c6dc37bf508149b28ce5b7d90ca4bbf9', 
                    type = 'APPLICATION', 
                    name = 'Active Directory [source]', ),
                created = '2020-07-11T21:23:15Z',
                modified = '2020-07-11T21:23:15Z',
                launched = '2020-07-11T21:23:15Z',
                completed = '2020-07-11T21:23:15Z',
                completion_status = 'SUCCESS',
                messages = [
                    sailpoint.beta.models.task_status_message.TaskStatusMessage(
                        type = 'INFO', 
                        localized_text = sailpoint.beta.models.localized_message.LocalizedMessage(
                            locale = 'An error has occurred!', 
                            message = 'Error has occurred!', ), 
                        key = 'akey', 
                        parameters = [{name=value}], )
                    ],
                returns = [
                    sailpoint.beta.models.task_return_details.TaskReturnDetails(
                        name = 'label', 
                        attribute_name = 'identityCount', )
                    ],
                attributes = {identityCount=0},
                progress = 'Started',
                percent_complete = 100,
                task_definition_summary = sailpoint.beta.models.task_definition_summary.TaskDefinitionSummary(
                    id = '2c91808475b4334b0175e1dff64b63c5', 
                    unique_name = 'Cloud Account Aggregation', 
                    description = 'Aggregates from the specified application.', 
                    parent_name = 'Cloud Account Aggregation', 
                    executor = 'sailpoint.task.ServiceTaskExecutor', 
                    arguments = { }, )
            )
        else:
            return TaskStatus(
                id = 'id12345',
                type = 'QUARTZ',
                unique_name = 'Big Task',
                description = 'A Really Big Task',
                parent_name = 'Parent Task',
                launcher = 'sweep',
                created = '2020-07-11T21:23:15Z',
                modified = '2020-07-11T21:23:15Z',
                launched = '2020-07-11T21:23:15Z',
                completed = '2020-07-11T21:23:15Z',
                completion_status = 'SUCCESS',
                messages = [
                    sailpoint.beta.models.task_status_message.TaskStatusMessage(
                        type = 'INFO', 
                        localized_text = sailpoint.beta.models.localized_message.LocalizedMessage(
                            locale = 'An error has occurred!', 
                            message = 'Error has occurred!', ), 
                        key = 'akey', 
                        parameters = [{name=value}], )
                    ],
                returns = [
                    sailpoint.beta.models.task_return_details.TaskReturnDetails(
                        name = 'label', 
                        attribute_name = 'identityCount', )
                    ],
                attributes = {identityCount=0},
                progress = 'Started',
                percent_complete = 100,
        )
        """

    def testTaskStatus(self):
        """Test TaskStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from sailpoint.v3.models.access import Access
from sailpoint.v3.models.access_constraint import AccessConstraint
from sailpoint.v3.models.access_criteria import AccessCriteria
from sailpoint.v3.models.access_criteria_criteria_list_inner import AccessCriteriaCriteriaListInner
from sailpoint.v3.models.access_item_requested_for import AccessItemRequestedFor
from sailpoint.v3.models.access_item_requester import AccessItemRequester
from sailpoint.v3.models.access_item_reviewed_by import AccessItemReviewedBy
from sailpoint.v3.models.access_profile import AccessProfile
from sailpoint.v3.models.access_profile_approval_scheme import AccessProfileApprovalScheme
from sailpoint.v3.models.access_profile_bulk_delete_request import AccessProfileBulkDeleteRequest
from sailpoint.v3.models.access_profile_bulk_delete_response import AccessProfileBulkDeleteResponse
from sailpoint.v3.models.access_profile_document import AccessProfileDocument
from sailpoint.v3.models.access_profile_document_all_of_source import AccessProfileDocumentAllOfSource
from sailpoint.v3.models.access_profile_entitlement import AccessProfileEntitlement
from sailpoint.v3.models.access_profile_ref import AccessProfileRef
from sailpoint.v3.models.access_profile_role import AccessProfileRole
from sailpoint.v3.models.access_profile_source_ref import AccessProfileSourceRef
from sailpoint.v3.models.access_profile_summary import AccessProfileSummary
from sailpoint.v3.models.access_profile_usage import AccessProfileUsage
from sailpoint.v3.models.access_profile_usage_used_by_inner import AccessProfileUsageUsedByInner
from sailpoint.v3.models.access_request import AccessRequest
from sailpoint.v3.models.access_request_config import AccessRequestConfig
from sailpoint.v3.models.access_request_item import AccessRequestItem
from sailpoint.v3.models.access_request_phases import AccessRequestPhases
from sailpoint.v3.models.access_request_type import AccessRequestType
from sailpoint.v3.models.access_review_item import AccessReviewItem
from sailpoint.v3.models.access_review_reassignment import AccessReviewReassignment
from sailpoint.v3.models.access_summary import AccessSummary
from sailpoint.v3.models.access_summary_access import AccessSummaryAccess
from sailpoint.v3.models.access_type import AccessType
from sailpoint.v3.models.account import Account
from sailpoint.v3.models.account_action import AccountAction
from sailpoint.v3.models.account_activity import AccountActivity
from sailpoint.v3.models.account_activity_approval_status import AccountActivityApprovalStatus
from sailpoint.v3.models.account_activity_document import AccountActivityDocument
from sailpoint.v3.models.account_activity_item import AccountActivityItem
from sailpoint.v3.models.account_activity_item_operation import AccountActivityItemOperation
from sailpoint.v3.models.account_activity_searched_item import AccountActivitySearchedItem
from sailpoint.v3.models.account_attributes import AccountAttributes
from sailpoint.v3.models.account_attributes_create import AccountAttributesCreate
from sailpoint.v3.models.account_attributes_create_attributes import AccountAttributesCreateAttributes
from sailpoint.v3.models.account_request import AccountRequest
from sailpoint.v3.models.account_request_info import AccountRequestInfo
from sailpoint.v3.models.account_request_result import AccountRequestResult
from sailpoint.v3.models.account_source import AccountSource
from sailpoint.v3.models.account_toggle_request import AccountToggleRequest
from sailpoint.v3.models.account_unlock_request import AccountUnlockRequest
from sailpoint.v3.models.account_usage import AccountUsage
from sailpoint.v3.models.accounts_async_result import AccountsAsyncResult
from sailpoint.v3.models.accounts_export_report_arguments import AccountsExportReportArguments
from sailpoint.v3.models.activate_campaign_options import ActivateCampaignOptions
from sailpoint.v3.models.activity_insights import ActivityInsights
from sailpoint.v3.models.admin_review_reassign import AdminReviewReassign
from sailpoint.v3.models.admin_review_reassign_reassign_to import AdminReviewReassignReassignTo
from sailpoint.v3.models.aggregation_result import AggregationResult
from sailpoint.v3.models.aggregation_type import AggregationType
from sailpoint.v3.models.aggregations import Aggregations
from sailpoint.v3.models.app import App
from sailpoint.v3.models.app_all_of_account import AppAllOfAccount
from sailpoint.v3.models.approval import Approval
from sailpoint.v3.models.approval_comment import ApprovalComment
from sailpoint.v3.models.approval_forward_history import ApprovalForwardHistory
from sailpoint.v3.models.approval_item_details import ApprovalItemDetails
from sailpoint.v3.models.approval_items import ApprovalItems
from sailpoint.v3.models.approval_reminder_and_escalation_config import ApprovalReminderAndEscalationConfig
from sailpoint.v3.models.approval_scheme import ApprovalScheme
from sailpoint.v3.models.approval_scheme_for_role import ApprovalSchemeForRole
from sailpoint.v3.models.approval_status import ApprovalStatus
from sailpoint.v3.models.approval_status_dto import ApprovalStatusDto
from sailpoint.v3.models.approval_status_dto_current_owner import ApprovalStatusDtoCurrentOwner
from sailpoint.v3.models.approval_status_dto_original_owner import ApprovalStatusDtoOriginalOwner
from sailpoint.v3.models.approval_summary import ApprovalSummary
from sailpoint.v3.models.array_inner import ArrayInner
from sailpoint.v3.models.attribute_definition import AttributeDefinition
from sailpoint.v3.models.attribute_definition_schema import AttributeDefinitionSchema
from sailpoint.v3.models.attribute_definition_type import AttributeDefinitionType
from sailpoint.v3.models.attribute_request import AttributeRequest
from sailpoint.v3.models.auth_user import AuthUser
from sailpoint.v3.models.base_access import BaseAccess
from sailpoint.v3.models.base_access_all_of_owner import BaseAccessAllOfOwner
from sailpoint.v3.models.base_access_profile import BaseAccessProfile
from sailpoint.v3.models.base_account import BaseAccount
from sailpoint.v3.models.base_common_dto import BaseCommonDto
from sailpoint.v3.models.base_document import BaseDocument
from sailpoint.v3.models.base_entitlement import BaseEntitlement
from sailpoint.v3.models.base_reference_dto import BaseReferenceDto
from sailpoint.v3.models.base_segment import BaseSegment
from sailpoint.v3.models.before_provisioning_rule_dto import BeforeProvisioningRuleDto
from sailpoint.v3.models.bound import Bound
from sailpoint.v3.models.branding_item import BrandingItem
from sailpoint.v3.models.branding_item_create import BrandingItemCreate
from sailpoint.v3.models.bucket_aggregation import BucketAggregation
from sailpoint.v3.models.bucket_type import BucketType
from sailpoint.v3.models.bulk_tagged_object import BulkTaggedObject
from sailpoint.v3.models.bulk_tagged_object_response import BulkTaggedObjectResponse
from sailpoint.v3.models.campaign import Campaign
from sailpoint.v3.models.campaign_alert import CampaignAlert
from sailpoint.v3.models.campaign_all_of_filter import CampaignAllOfFilter
from sailpoint.v3.models.campaign_all_of_role_composition_campaign_info import CampaignAllOfRoleCompositionCampaignInfo
from sailpoint.v3.models.campaign_all_of_role_composition_campaign_info_remediator_ref import CampaignAllOfRoleCompositionCampaignInfoRemediatorRef
from sailpoint.v3.models.campaign_all_of_search_campaign_info import CampaignAllOfSearchCampaignInfo
from sailpoint.v3.models.campaign_all_of_search_campaign_info_reviewer import CampaignAllOfSearchCampaignInfoReviewer
from sailpoint.v3.models.campaign_all_of_source_owner_campaign_info import CampaignAllOfSourceOwnerCampaignInfo
from sailpoint.v3.models.campaign_all_of_sources_with_orphan_entitlements import CampaignAllOfSourcesWithOrphanEntitlements
from sailpoint.v3.models.campaign_complete_options import CampaignCompleteOptions
from sailpoint.v3.models.campaign_filter_details import CampaignFilterDetails
from sailpoint.v3.models.campaign_filter_details_criteria_list_inner import CampaignFilterDetailsCriteriaListInner
from sailpoint.v3.models.campaign_reference import CampaignReference
from sailpoint.v3.models.campaign_report import CampaignReport
from sailpoint.v3.models.campaign_reports_config import CampaignReportsConfig
from sailpoint.v3.models.campaign_template import CampaignTemplate
from sailpoint.v3.models.campaign_template_owner_ref import CampaignTemplateOwnerRef
from sailpoint.v3.models.campaigns_delete_request import CampaignsDeleteRequest
from sailpoint.v3.models.cancel_access_request import CancelAccessRequest
from sailpoint.v3.models.cancelled_request_details import CancelledRequestDetails
from sailpoint.v3.models.certification import Certification
from sailpoint.v3.models.certification_decision import CertificationDecision
from sailpoint.v3.models.certification_identity_summary import CertificationIdentitySummary
from sailpoint.v3.models.certification_phase import CertificationPhase
from sailpoint.v3.models.certification_reference import CertificationReference
from sailpoint.v3.models.certification_task import CertificationTask
from sailpoint.v3.models.client_log_configuration import ClientLogConfiguration
from sailpoint.v3.models.client_type import ClientType
from sailpoint.v3.models.column import Column
from sailpoint.v3.models.comment import Comment
from sailpoint.v3.models.comment_dto import CommentDto
from sailpoint.v3.models.comment_dto_author import CommentDtoAuthor
from sailpoint.v3.models.completed_approval import CompletedApproval
from sailpoint.v3.models.completed_approval_pre_approval_trigger_result import CompletedApprovalPreApprovalTriggerResult
from sailpoint.v3.models.completed_approval_requester_comment import CompletedApprovalRequesterComment
from sailpoint.v3.models.completed_approval_reviewer_comment import CompletedApprovalReviewerComment
from sailpoint.v3.models.completed_approval_state import CompletedApprovalState
from sailpoint.v3.models.completion_status import CompletionStatus
from sailpoint.v3.models.conflicting_access_criteria import ConflictingAccessCriteria
from sailpoint.v3.models.connector_detail import ConnectorDetail
from sailpoint.v3.models.create_external_execute_workflow200_response import CreateExternalExecuteWorkflow200Response
from sailpoint.v3.models.create_external_execute_workflow_request import CreateExternalExecuteWorkflowRequest
from sailpoint.v3.models.create_o_auth_client_request import CreateOAuthClientRequest
from sailpoint.v3.models.create_o_auth_client_response import CreateOAuthClientResponse
from sailpoint.v3.models.create_personal_access_token_request import CreatePersonalAccessTokenRequest
from sailpoint.v3.models.create_personal_access_token_response import CreatePersonalAccessTokenResponse
from sailpoint.v3.models.create_saved_search_request import CreateSavedSearchRequest
from sailpoint.v3.models.create_scheduled_search_request import CreateScheduledSearchRequest
from sailpoint.v3.models.create_workflow_request import CreateWorkflowRequest
from sailpoint.v3.models.criteria_type import CriteriaType
from sailpoint.v3.models.data_access import DataAccess
from sailpoint.v3.models.data_access_categories_inner import DataAccessCategoriesInner
from sailpoint.v3.models.data_access_impact_score import DataAccessImpactScore
from sailpoint.v3.models.data_access_policies_inner import DataAccessPoliciesInner
from sailpoint.v3.models.delete_non_employee_records_in_bulk_request import DeleteNonEmployeeRecordsInBulkRequest
from sailpoint.v3.models.delete_source202_response import DeleteSource202Response
from sailpoint.v3.models.delete_vendor_connector_mapping200_response import DeleteVendorConnectorMapping200Response
from sailpoint.v3.models.discovered_applications_inner import DiscoveredApplicationsInner
from sailpoint.v3.models.display_reference import DisplayReference
from sailpoint.v3.models.document_type import DocumentType
from sailpoint.v3.models.dto_type import DtoType
from sailpoint.v3.models.duo_verification_request import DuoVerificationRequest
from sailpoint.v3.models.email_notification_option import EmailNotificationOption
from sailpoint.v3.models.entitlement import Entitlement
from sailpoint.v3.models.entitlement_document import EntitlementDocument
from sailpoint.v3.models.entitlement_document_all_of_source import EntitlementDocumentAllOfSource
from sailpoint.v3.models.entitlement_dto import EntitlementDto
from sailpoint.v3.models.entitlement_ref import EntitlementRef
from sailpoint.v3.models.entitlement_ref1 import EntitlementRef1
from sailpoint.v3.models.entitlement_request_config import EntitlementRequestConfig
from sailpoint.v3.models.entitlement_source import EntitlementSource
from sailpoint.v3.models.entitlement_summary import EntitlementSummary
from sailpoint.v3.models.error_message_dto import ErrorMessageDto
from sailpoint.v3.models.error_response_dto import ErrorResponseDto
from sailpoint.v3.models.event import Event
from sailpoint.v3.models.event_attributes import EventAttributes
from sailpoint.v3.models.event_document import EventDocument
from sailpoint.v3.models.exception_access_criteria import ExceptionAccessCriteria
from sailpoint.v3.models.exception_criteria import ExceptionCriteria
from sailpoint.v3.models.exception_criteria_access import ExceptionCriteriaAccess
from sailpoint.v3.models.exception_criteria_criteria_list_inner import ExceptionCriteriaCriteriaListInner
from sailpoint.v3.models.execution_status import ExecutionStatus
from sailpoint.v3.models.expansion_item import ExpansionItem
from sailpoint.v3.models.expression import Expression
from sailpoint.v3.models.expression_children_inner import ExpressionChildrenInner
from sailpoint.v3.models.external_attributes import ExternalAttributes
from sailpoint.v3.models.federation_protocol_details import FederationProtocolDetails
from sailpoint.v3.models.field_details_dto import FieldDetailsDto
from sailpoint.v3.models.filter import Filter
from sailpoint.v3.models.filter_aggregation import FilterAggregation
from sailpoint.v3.models.filter_type import FilterType
from sailpoint.v3.models.form_details import FormDetails
from sailpoint.v3.models.form_item_details import FormItemDetails
from sailpoint.v3.models.forward_approval_dto import ForwardApprovalDto
from sailpoint.v3.models.get_active_campaigns200_response_inner import GetActiveCampaigns200ResponseInner
from sailpoint.v3.models.get_o_auth_client_response import GetOAuthClientResponse
from sailpoint.v3.models.get_personal_access_token_response import GetPersonalAccessTokenResponse
from sailpoint.v3.models.get_vendor_connector_mappings405_response import GetVendorConnectorMappings405Response
from sailpoint.v3.models.grant_type import GrantType
from sailpoint.v3.models.identities_details_report_arguments import IdentitiesDetailsReportArguments
from sailpoint.v3.models.identities_report_arguments import IdentitiesReportArguments
from sailpoint.v3.models.identity_access import IdentityAccess
from sailpoint.v3.models.identity_attribute import IdentityAttribute
from sailpoint.v3.models.identity_attribute_config import IdentityAttributeConfig
from sailpoint.v3.models.identity_attribute_transform import IdentityAttributeTransform
from sailpoint.v3.models.identity_cert_decision_summary import IdentityCertDecisionSummary
from sailpoint.v3.models.identity_certification_dto import IdentityCertificationDto
from sailpoint.v3.models.identity_document import IdentityDocument
from sailpoint.v3.models.identity_document_all_of_identity_profile import IdentityDocumentAllOfIdentityProfile
from sailpoint.v3.models.identity_document_all_of_manager import IdentityDocumentAllOfManager
from sailpoint.v3.models.identity_document_all_of_source import IdentityDocumentAllOfSource
from sailpoint.v3.models.identity_exception_report_reference import IdentityExceptionReportReference
from sailpoint.v3.models.identity_profile import IdentityProfile
from sailpoint.v3.models.identity_profile_all_of_authoritative_source import IdentityProfileAllOfAuthoritativeSource
from sailpoint.v3.models.identity_profile_all_of_owner import IdentityProfileAllOfOwner
from sailpoint.v3.models.identity_profile_exported_object import IdentityProfileExportedObject
from sailpoint.v3.models.identity_profile_exported_object_self import IdentityProfileExportedObjectSelf
from sailpoint.v3.models.identity_profile_identity_error_report_arguments import IdentityProfileIdentityErrorReportArguments
from sailpoint.v3.models.identity_reference import IdentityReference
from sailpoint.v3.models.identity_reference_with_name_and_email import IdentityReferenceWithNameAndEmail
from sailpoint.v3.models.identity_summary import IdentitySummary
from sailpoint.v3.models.identity_with_new_access import IdentityWithNewAccess
from sailpoint.v3.models.identity_with_new_access1 import IdentityWithNewAccess1
from sailpoint.v3.models.identity_with_new_access_access_refs_inner import IdentityWithNewAccessAccessRefsInner
from sailpoint.v3.models.idp_details import IdpDetails
from sailpoint.v3.models.import_non_employee_records_in_bulk_request import ImportNonEmployeeRecordsInBulkRequest
from sailpoint.v3.models.import_object import ImportObject
from sailpoint.v3.models.import_uploaded_backup_request import ImportUploadedBackupRequest
from sailpoint.v3.models.index import Index
from sailpoint.v3.models.inner_hit import InnerHit
from sailpoint.v3.models.jit_configuration import JITConfiguration
from sailpoint.v3.models.json_patch_operation import JsonPatchOperation
from sailpoint.v3.models.json_patch_operation_value import JsonPatchOperationValue
from sailpoint.v3.models.kba_answer_request_item import KbaAnswerRequestItem
from sailpoint.v3.models.kba_answer_response_item import KbaAnswerResponseItem
from sailpoint.v3.models.kba_auth_response import KbaAuthResponse
from sailpoint.v3.models.kba_auth_response_item import KbaAuthResponseItem
from sailpoint.v3.models.kba_question import KbaQuestion
from sailpoint.v3.models.lifecycle_state import LifecycleState
from sailpoint.v3.models.lifecyclestate_deleted import LifecyclestateDeleted
from sailpoint.v3.models.list_access_profiles401_response import ListAccessProfiles401Response
from sailpoint.v3.models.list_access_profiles429_response import ListAccessProfiles429Response
from sailpoint.v3.models.list_campaign_filters200_response import ListCampaignFilters200Response
from sailpoint.v3.models.list_complete_workflow_library200_response_inner import ListCompleteWorkflowLibrary200ResponseInner
from sailpoint.v3.models.locale_origin import LocaleOrigin
from sailpoint.v3.models.lockout_configuration import LockoutConfiguration
from sailpoint.v3.models.managed_client import ManagedClient
from sailpoint.v3.models.managed_client_request import ManagedClientRequest
from sailpoint.v3.models.managed_client_status import ManagedClientStatus
from sailpoint.v3.models.managed_client_status_code import ManagedClientStatusCode
from sailpoint.v3.models.managed_client_type import ManagedClientType
from sailpoint.v3.models.managed_cluster import ManagedCluster
from sailpoint.v3.models.managed_cluster_attributes import ManagedClusterAttributes
from sailpoint.v3.models.managed_cluster_key_pair import ManagedClusterKeyPair
from sailpoint.v3.models.managed_cluster_queue import ManagedClusterQueue
from sailpoint.v3.models.managed_cluster_redis import ManagedClusterRedis
from sailpoint.v3.models.managed_cluster_request import ManagedClusterRequest
from sailpoint.v3.models.managed_cluster_types import ManagedClusterTypes
from sailpoint.v3.models.manager_correlation_mapping import ManagerCorrelationMapping
from sailpoint.v3.models.manual_discover_applications import ManualDiscoverApplications
from sailpoint.v3.models.manual_discover_applications_template import ManualDiscoverApplicationsTemplate
from sailpoint.v3.models.manual_work_item_details import ManualWorkItemDetails
from sailpoint.v3.models.manual_work_item_details_current_owner import ManualWorkItemDetailsCurrentOwner
from sailpoint.v3.models.manual_work_item_details_original_owner import ManualWorkItemDetailsOriginalOwner
from sailpoint.v3.models.manual_work_item_state import ManualWorkItemState
from sailpoint.v3.models.metric_aggregation import MetricAggregation
from sailpoint.v3.models.metric_type import MetricType
from sailpoint.v3.models.mfa_config_test_response import MfaConfigTestResponse
from sailpoint.v3.models.mfa_duo_config import MfaDuoConfig
from sailpoint.v3.models.mfa_okta_config import MfaOktaConfig
from sailpoint.v3.models.model_schema import ModelSchema
from sailpoint.v3.models.multi_policy_request import MultiPolicyRequest
from sailpoint.v3.models.nested_aggregation import NestedAggregation
from sailpoint.v3.models.network_configuration import NetworkConfiguration
from sailpoint.v3.models.non_employee_approval_decision import NonEmployeeApprovalDecision
from sailpoint.v3.models.non_employee_approval_item import NonEmployeeApprovalItem
from sailpoint.v3.models.non_employee_approval_item_base import NonEmployeeApprovalItemBase
from sailpoint.v3.models.non_employee_approval_item_detail import NonEmployeeApprovalItemDetail
from sailpoint.v3.models.non_employee_approval_summary import NonEmployeeApprovalSummary
from sailpoint.v3.models.non_employee_bulk_upload_job import NonEmployeeBulkUploadJob
from sailpoint.v3.models.non_employee_bulk_upload_status import NonEmployeeBulkUploadStatus
from sailpoint.v3.models.non_employee_identity_dto_type import NonEmployeeIdentityDtoType
from sailpoint.v3.models.non_employee_identity_reference_with_id import NonEmployeeIdentityReferenceWithId
from sailpoint.v3.models.non_employee_idn_user_request import NonEmployeeIdnUserRequest
from sailpoint.v3.models.non_employee_record import NonEmployeeRecord
from sailpoint.v3.models.non_employee_reject_approval_decision import NonEmployeeRejectApprovalDecision
from sailpoint.v3.models.non_employee_request import NonEmployeeRequest
from sailpoint.v3.models.non_employee_request_body import NonEmployeeRequestBody
from sailpoint.v3.models.non_employee_request_lite import NonEmployeeRequestLite
from sailpoint.v3.models.non_employee_request_summary import NonEmployeeRequestSummary
from sailpoint.v3.models.non_employee_request_without_approval_item import NonEmployeeRequestWithoutApprovalItem
from sailpoint.v3.models.non_employee_schema_attribute import NonEmployeeSchemaAttribute
from sailpoint.v3.models.non_employee_schema_attribute_body import NonEmployeeSchemaAttributeBody
from sailpoint.v3.models.non_employee_schema_attribute_type import NonEmployeeSchemaAttributeType
from sailpoint.v3.models.non_employee_source import NonEmployeeSource
from sailpoint.v3.models.non_employee_source_lite import NonEmployeeSourceLite
from sailpoint.v3.models.non_employee_source_lite_with_schema_attributes import NonEmployeeSourceLiteWithSchemaAttributes
from sailpoint.v3.models.non_employee_source_request_body import NonEmployeeSourceRequestBody
from sailpoint.v3.models.non_employee_source_with_cloud_external_id import NonEmployeeSourceWithCloudExternalId
from sailpoint.v3.models.non_employee_source_with_ne_count import NonEmployeeSourceWithNECount
from sailpoint.v3.models.object_import_result import ObjectImportResult
from sailpoint.v3.models.object_mapping_bulk_create_request import ObjectMappingBulkCreateRequest
from sailpoint.v3.models.object_mapping_bulk_create_response import ObjectMappingBulkCreateResponse
from sailpoint.v3.models.object_mapping_bulk_patch_request import ObjectMappingBulkPatchRequest
from sailpoint.v3.models.object_mapping_bulk_patch_response import ObjectMappingBulkPatchResponse
from sailpoint.v3.models.object_mapping_request import ObjectMappingRequest
from sailpoint.v3.models.object_mapping_response import ObjectMappingResponse
from sailpoint.v3.models.okta_verification_request import OktaVerificationRequest
from sailpoint.v3.models.operation import Operation
from sailpoint.v3.models.original_request import OriginalRequest
from sailpoint.v3.models.orphan_uncorrelated_report_arguments import OrphanUncorrelatedReportArguments
from sailpoint.v3.models.owner_dto import OwnerDto
from sailpoint.v3.models.owner_reference import OwnerReference
from sailpoint.v3.models.owner_reference_segments import OwnerReferenceSegments
from sailpoint.v3.models.owns import Owns
from sailpoint.v3.models.password_change_request import PasswordChangeRequest
from sailpoint.v3.models.password_change_response import PasswordChangeResponse
from sailpoint.v3.models.password_info import PasswordInfo
from sailpoint.v3.models.password_info_account import PasswordInfoAccount
from sailpoint.v3.models.password_info_query_dto import PasswordInfoQueryDTO
from sailpoint.v3.models.password_org_config import PasswordOrgConfig
from sailpoint.v3.models.password_policy_v3_dto import PasswordPolicyV3Dto
from sailpoint.v3.models.password_status import PasswordStatus
from sailpoint.v3.models.password_sync_group import PasswordSyncGroup
from sailpoint.v3.models.pat_owner import PatOwner
from sailpoint.v3.models.patch_service_desk_integration_request import PatchServiceDeskIntegrationRequest
from sailpoint.v3.models.pending_approval import PendingApproval
from sailpoint.v3.models.pending_approval_action import PendingApprovalAction
from sailpoint.v3.models.pending_approval_owner import PendingApprovalOwner
from sailpoint.v3.models.permission_dto import PermissionDto
from sailpoint.v3.models.pre_approval_trigger_details import PreApprovalTriggerDetails
from sailpoint.v3.models.processing_details import ProcessingDetails
from sailpoint.v3.models.provisioning_config import ProvisioningConfig
from sailpoint.v3.models.provisioning_config_plan_initializer_script import ProvisioningConfigPlanInitializerScript
from sailpoint.v3.models.provisioning_criteria_level1 import ProvisioningCriteriaLevel1
from sailpoint.v3.models.provisioning_criteria_level2 import ProvisioningCriteriaLevel2
from sailpoint.v3.models.provisioning_criteria_level3 import ProvisioningCriteriaLevel3
from sailpoint.v3.models.provisioning_criteria_operation import ProvisioningCriteriaOperation
from sailpoint.v3.models.provisioning_details import ProvisioningDetails
from sailpoint.v3.models.provisioning_policy import ProvisioningPolicy
from sailpoint.v3.models.provisioning_policy_dto import ProvisioningPolicyDto
from sailpoint.v3.models.provisioning_state import ProvisioningState
from sailpoint.v3.models.public_identity import PublicIdentity
from sailpoint.v3.models.public_identity_attribute_config import PublicIdentityAttributeConfig
from sailpoint.v3.models.public_identity_config import PublicIdentityConfig
from sailpoint.v3.models.put_correlation_config_request import PutCorrelationConfigRequest
from sailpoint.v3.models.put_password_dictionary_request import PutPasswordDictionaryRequest
from sailpoint.v3.models.put_source_config_request import PutSourceConfigRequest
from sailpoint.v3.models.put_source_template_request import PutSourceTemplateRequest
from sailpoint.v3.models.query import Query
from sailpoint.v3.models.query_result_filter import QueryResultFilter
from sailpoint.v3.models.query_type import QueryType
from sailpoint.v3.models.queued_check_config_details import QueuedCheckConfigDetails
from sailpoint.v3.models.range import Range
from sailpoint.v3.models.reassign_reference import ReassignReference
from sailpoint.v3.models.reassignment import Reassignment
from sailpoint.v3.models.reassignment_reference import ReassignmentReference
from sailpoint.v3.models.reassignment_trail_dto import ReassignmentTrailDTO
from sailpoint.v3.models.reassignment_type import ReassignmentType
from sailpoint.v3.models.reference import Reference
from sailpoint.v3.models.remediation_item_details import RemediationItemDetails
from sailpoint.v3.models.remediation_items import RemediationItems
from sailpoint.v3.models.report_details import ReportDetails
from sailpoint.v3.models.report_details_arguments import ReportDetailsArguments
from sailpoint.v3.models.report_result_reference import ReportResultReference
from sailpoint.v3.models.report_results import ReportResults
from sailpoint.v3.models.report_type import ReportType
from sailpoint.v3.models.request_on_behalf_of_config import RequestOnBehalfOfConfig
from sailpoint.v3.models.requestability import Requestability
from sailpoint.v3.models.requestability_for_role import RequestabilityForRole
from sailpoint.v3.models.requestable_object import RequestableObject
from sailpoint.v3.models.requestable_object_reference import RequestableObjectReference
from sailpoint.v3.models.requestable_object_request_status import RequestableObjectRequestStatus
from sailpoint.v3.models.requestable_object_type import RequestableObjectType
from sailpoint.v3.models.requested_item_status import RequestedItemStatus
from sailpoint.v3.models.requested_item_status_cancelled_request_details import RequestedItemStatusCancelledRequestDetails
from sailpoint.v3.models.requested_item_status_pre_approval_trigger_details import RequestedItemStatusPreApprovalTriggerDetails
from sailpoint.v3.models.requested_item_status_provisioning_details import RequestedItemStatusProvisioningDetails
from sailpoint.v3.models.requested_item_status_request_state import RequestedItemStatusRequestState
from sailpoint.v3.models.requested_item_status_requested_for import RequestedItemStatusRequestedFor
from sailpoint.v3.models.requested_item_status_requester_comment import RequestedItemStatusRequesterComment
from sailpoint.v3.models.requested_item_status_sod_violation_context import RequestedItemStatusSodViolationContext
from sailpoint.v3.models.review_decision import ReviewDecision
from sailpoint.v3.models.review_reassign import ReviewReassign
from sailpoint.v3.models.review_recommendation import ReviewRecommendation
from sailpoint.v3.models.reviewable_access_profile import ReviewableAccessProfile
from sailpoint.v3.models.reviewable_entitlement import ReviewableEntitlement
from sailpoint.v3.models.reviewable_entitlement_account import ReviewableEntitlementAccount
from sailpoint.v3.models.reviewable_role import ReviewableRole
from sailpoint.v3.models.reviewer import Reviewer
from sailpoint.v3.models.revocability import Revocability
from sailpoint.v3.models.revocability_for_role import RevocabilityForRole
from sailpoint.v3.models.role import Role
from sailpoint.v3.models.role_assignment_source_type import RoleAssignmentSourceType
from sailpoint.v3.models.role_bulk_delete_request import RoleBulkDeleteRequest
from sailpoint.v3.models.role_criteria_key import RoleCriteriaKey
from sailpoint.v3.models.role_criteria_key_type import RoleCriteriaKeyType
from sailpoint.v3.models.role_criteria_level1 import RoleCriteriaLevel1
from sailpoint.v3.models.role_criteria_level2 import RoleCriteriaLevel2
from sailpoint.v3.models.role_criteria_level3 import RoleCriteriaLevel3
from sailpoint.v3.models.role_criteria_operation import RoleCriteriaOperation
from sailpoint.v3.models.role_document import RoleDocument
from sailpoint.v3.models.role_identity import RoleIdentity
from sailpoint.v3.models.role_membership_identity import RoleMembershipIdentity
from sailpoint.v3.models.role_membership_selector import RoleMembershipSelector
from sailpoint.v3.models.role_membership_selector_type import RoleMembershipSelectorType
from sailpoint.v3.models.role_summary import RoleSummary
from sailpoint.v3.models.saved_search import SavedSearch
from sailpoint.v3.models.saved_search_detail import SavedSearchDetail
from sailpoint.v3.models.saved_search_detail_filters import SavedSearchDetailFilters
from sailpoint.v3.models.saved_search_name import SavedSearchName
from sailpoint.v3.models.schedule import Schedule
from sailpoint.v3.models.schedule1 import Schedule1
from sailpoint.v3.models.schedule1_days import Schedule1Days
from sailpoint.v3.models.schedule1_hours import Schedule1Hours
from sailpoint.v3.models.schedule1_months import Schedule1Months
from sailpoint.v3.models.schedule_days import ScheduleDays
from sailpoint.v3.models.schedule_hours import ScheduleHours
from sailpoint.v3.models.schedule_months import ScheduleMonths
from sailpoint.v3.models.schedule_type import ScheduleType
from sailpoint.v3.models.scheduled_attributes import ScheduledAttributes
from sailpoint.v3.models.scheduled_search import ScheduledSearch
from sailpoint.v3.models.scheduled_search_all_of_owner import ScheduledSearchAllOfOwner
from sailpoint.v3.models.scheduled_search_name import ScheduledSearchName
from sailpoint.v3.models.search import Search
from sailpoint.v3.models.search_aggregation_specification import SearchAggregationSpecification
from sailpoint.v3.models.search_arguments import SearchArguments
from sailpoint.v3.models.search_export_report_arguments import SearchExportReportArguments
from sailpoint.v3.models.search_filter_type import SearchFilterType
from sailpoint.v3.models.search_schedule import SearchSchedule
from sailpoint.v3.models.search_schedule_recipients_inner import SearchScheduleRecipientsInner
from sailpoint.v3.models.section_details import SectionDetails
from sailpoint.v3.models.segment import Segment
from sailpoint.v3.models.segment_visibility_criteria import SegmentVisibilityCriteria
from sailpoint.v3.models.selector import Selector
from sailpoint.v3.models.selector_type import SelectorType
from sailpoint.v3.models.send_token_request import SendTokenRequest
from sailpoint.v3.models.send_token_response import SendTokenResponse
from sailpoint.v3.models.service_desk_integration_dto import ServiceDeskIntegrationDto
from sailpoint.v3.models.service_desk_integration_dto_all_of_before_provisioning_rule import ServiceDeskIntegrationDtoAllOfBeforeProvisioningRule
from sailpoint.v3.models.service_desk_integration_dto_all_of_cluster_ref import ServiceDeskIntegrationDtoAllOfClusterRef
from sailpoint.v3.models.service_desk_integration_dto_all_of_owner_ref import ServiceDeskIntegrationDtoAllOfOwnerRef
from sailpoint.v3.models.service_desk_integration_template_dto import ServiceDeskIntegrationTemplateDto
from sailpoint.v3.models.service_desk_integration_template_type import ServiceDeskIntegrationTemplateType
from sailpoint.v3.models.service_desk_source import ServiceDeskSource
from sailpoint.v3.models.service_provider_configuration import ServiceProviderConfiguration
from sailpoint.v3.models.service_provider_configuration_federation_protocol_details_inner import ServiceProviderConfigurationFederationProtocolDetailsInner
from sailpoint.v3.models.session_configuration import SessionConfiguration
from sailpoint.v3.models.set_lifecycle_state200_response import SetLifecycleState200Response
from sailpoint.v3.models.set_lifecycle_state_request import SetLifecycleStateRequest
from sailpoint.v3.models.slim_campaign import SlimCampaign
from sailpoint.v3.models.sod_exempt_criteria import SodExemptCriteria
from sailpoint.v3.models.sod_policy import SodPolicy
from sailpoint.v3.models.sod_policy_conflicting_access_criteria import SodPolicyConflictingAccessCriteria
from sailpoint.v3.models.sod_policy_dto import SodPolicyDto
from sailpoint.v3.models.sod_policy_owner_ref import SodPolicyOwnerRef
from sailpoint.v3.models.sod_policy_schedule import SodPolicySchedule
from sailpoint.v3.models.sod_recipient import SodRecipient
from sailpoint.v3.models.sod_report_result_dto import SodReportResultDto
from sailpoint.v3.models.sod_violation_check import SodViolationCheck
from sailpoint.v3.models.sod_violation_check_result import SodViolationCheckResult
from sailpoint.v3.models.sod_violation_context import SodViolationContext
from sailpoint.v3.models.sod_violation_context_check_completed import SodViolationContextCheckCompleted
from sailpoint.v3.models.sod_violation_context_conflicting_access_criteria import SodViolationContextConflictingAccessCriteria
from sailpoint.v3.models.sod_violation_context_conflicting_access_criteria_left_criteria import SodViolationContextConflictingAccessCriteriaLeftCriteria
from sailpoint.v3.models.source import Source
from sailpoint.v3.models.source_account_correlation_config import SourceAccountCorrelationConfig
from sailpoint.v3.models.source_account_correlation_rule import SourceAccountCorrelationRule
from sailpoint.v3.models.source_before_provisioning_rule import SourceBeforeProvisioningRule
from sailpoint.v3.models.source_cluster import SourceCluster
from sailpoint.v3.models.source_cluster_dto import SourceClusterDto
from sailpoint.v3.models.source_health_dto import SourceHealthDto
from sailpoint.v3.models.source_management_workgroup import SourceManagementWorkgroup
from sailpoint.v3.models.source_manager_correlation_mapping import SourceManagerCorrelationMapping
from sailpoint.v3.models.source_manager_correlation_rule import SourceManagerCorrelationRule
from sailpoint.v3.models.source_owner import SourceOwner
from sailpoint.v3.models.source_password_policies_inner import SourcePasswordPoliciesInner
from sailpoint.v3.models.source_schemas_inner import SourceSchemasInner
from sailpoint.v3.models.source_usage import SourceUsage
from sailpoint.v3.models.source_usage_status import SourceUsageStatus
from sailpoint.v3.models.sp_config_message import SpConfigMessage
from sailpoint.v3.models.sp_details import SpDetails
from sailpoint.v3.models.standard_level import StandardLevel
from sailpoint.v3.models.sub_search_aggregation_specification import SubSearchAggregationSpecification
from sailpoint.v3.models.tagged_object import TaggedObject
from sailpoint.v3.models.tagged_object_dto import TaggedObjectDto
from sailpoint.v3.models.task_result_details import TaskResultDetails
from sailpoint.v3.models.task_result_details_messages_inner import TaskResultDetailsMessagesInner
from sailpoint.v3.models.task_result_details_returns_inner import TaskResultDetailsReturnsInner
from sailpoint.v3.models.task_result_dto import TaskResultDto
from sailpoint.v3.models.task_result_simplified import TaskResultSimplified
from sailpoint.v3.models.test_external_execute_workflow200_response import TestExternalExecuteWorkflow200Response
from sailpoint.v3.models.test_external_execute_workflow_request import TestExternalExecuteWorkflowRequest
from sailpoint.v3.models.test_workflow200_response import TestWorkflow200Response
from sailpoint.v3.models.test_workflow_request import TestWorkflowRequest
from sailpoint.v3.models.text_query import TextQuery
from sailpoint.v3.models.token_auth_request import TokenAuthRequest
from sailpoint.v3.models.token_auth_response import TokenAuthResponse
from sailpoint.v3.models.transform import Transform
from sailpoint.v3.models.transform_definition import TransformDefinition
from sailpoint.v3.models.transform_definition_attributes_value import TransformDefinitionAttributesValue
from sailpoint.v3.models.transform_read import TransformRead
from sailpoint.v3.models.type_ahead_query import TypeAheadQuery
from sailpoint.v3.models.typed_reference import TypedReference
from sailpoint.v3.models.update_detail import UpdateDetail
from sailpoint.v3.models.uploads_request import UploadsRequest
from sailpoint.v3.models.uploads_response import UploadsResponse
from sailpoint.v3.models.usage_type import UsageType
from sailpoint.v3.models.v3_connector_dto import V3ConnectorDto
from sailpoint.v3.models.v3_create_connector_dto import V3CreateConnectorDto
from sailpoint.v3.models.value import Value
from sailpoint.v3.models.vendor_connector_mapping import VendorConnectorMapping
from sailpoint.v3.models.vendor_connector_mapping_deleted_at import VendorConnectorMappingDeletedAt
from sailpoint.v3.models.vendor_connector_mapping_deleted_by import VendorConnectorMappingDeletedBy
from sailpoint.v3.models.vendor_connector_mapping_updated_at import VendorConnectorMappingUpdatedAt
from sailpoint.v3.models.vendor_connector_mapping_updated_by import VendorConnectorMappingUpdatedBy
from sailpoint.v3.models.verification_poll_request import VerificationPollRequest
from sailpoint.v3.models.verification_response import VerificationResponse
from sailpoint.v3.models.violation_context import ViolationContext
from sailpoint.v3.models.violation_context_policy import ViolationContextPolicy
from sailpoint.v3.models.violation_owner_assignment_config import ViolationOwnerAssignmentConfig
from sailpoint.v3.models.violation_owner_assignment_config_owner_ref import ViolationOwnerAssignmentConfigOwnerRef
from sailpoint.v3.models.violation_prediction import ViolationPrediction
from sailpoint.v3.models.visibility_criteria import VisibilityCriteria
from sailpoint.v3.models.work_item_state import WorkItemState
from sailpoint.v3.models.work_item_state_manual_work_items import WorkItemStateManualWorkItems
from sailpoint.v3.models.work_item_type_manual_work_items import WorkItemTypeManualWorkItems
from sailpoint.v3.models.work_items import WorkItems
from sailpoint.v3.models.work_items_count import WorkItemsCount
from sailpoint.v3.models.work_items_form import WorkItemsForm
from sailpoint.v3.models.work_items_summary import WorkItemsSummary
from sailpoint.v3.models.workflow import Workflow
from sailpoint.v3.models.workflow_all_of_creator import WorkflowAllOfCreator
from sailpoint.v3.models.workflow_body import WorkflowBody
from sailpoint.v3.models.workflow_body_owner import WorkflowBodyOwner
from sailpoint.v3.models.workflow_definition import WorkflowDefinition
from sailpoint.v3.models.workflow_execution import WorkflowExecution
from sailpoint.v3.models.workflow_execution_event import WorkflowExecutionEvent
from sailpoint.v3.models.workflow_library_action import WorkflowLibraryAction
from sailpoint.v3.models.workflow_library_form_fields import WorkflowLibraryFormFields
from sailpoint.v3.models.workflow_library_operator import WorkflowLibraryOperator
from sailpoint.v3.models.workflow_library_trigger import WorkflowLibraryTrigger
from sailpoint.v3.models.workflow_o_auth_client import WorkflowOAuthClient
from sailpoint.v3.models.workflow_trigger import WorkflowTrigger
from sailpoint.v3.models.workflow_trigger_attributes import WorkflowTriggerAttributes



# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class PasswordPolicyV3Dto(BaseModel):
    """
    PasswordPolicyV3Dto
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The password policy Id.")
    description: Optional[StrictStr] = Field(default=None, description="Description for current password policy.")
    name: Optional[StrictStr] = Field(default=None, description="The name of the password policy.")
    date_created: Optional[datetime] = Field(default=None, description="Date the Password Policy was created.", alias="dateCreated")
    last_updated: Optional[datetime] = Field(default=None, description="Date the Password Policy was updated.", alias="lastUpdated")
    first_expiration_reminder: Optional[StrictInt] = Field(default=None, description="The number of days before expiration remaninder.", alias="firstExpirationReminder")
    account_id_min_word_length: Optional[StrictInt] = Field(default=None, description="The minimun length of account Id. By default is equals to -1.", alias="accountIdMinWordLength")
    account_name_min_word_length: Optional[StrictInt] = Field(default=None, description="The minimun length of account name. By default is equals to -1.", alias="accountNameMinWordLength")
    min_alpha: Optional[StrictInt] = Field(default=None, description="Maximum alpha. By default is equals to 0.", alias="minAlpha")
    min_character_types: Optional[StrictInt] = Field(default=None, description="MinCharacterTypes. By default is equals to -1.", alias="minCharacterTypes")
    max_length: Optional[StrictInt] = Field(default=None, description="Maximum length of the password.", alias="maxLength")
    min_length: Optional[StrictInt] = Field(default=None, description="Minimum length of the password. By default is equals to 0.", alias="minLength")
    max_repeated_chars: Optional[StrictInt] = Field(default=None, description="Maximum repetition of the same character in the password. By default is equals to -1.", alias="maxRepeatedChars")
    min_lower: Optional[StrictInt] = Field(default=None, description="Minimum amount of lower case character in the password. By default is equals to 0.", alias="minLower")
    min_numeric: Optional[StrictInt] = Field(default=None, description="Minimum amount of numeric characters in the password. By default is equals to 0.", alias="minNumeric")
    min_special: Optional[StrictInt] = Field(default=None, description="Minimum amount of special symbols in the password. By default is equals to 0.", alias="minSpecial")
    min_upper: Optional[StrictInt] = Field(default=None, description="Minimum amount of upper case symbols in the password. By default is equals to 0.", alias="minUpper")
    password_expiration: Optional[StrictInt] = Field(default=None, description="Number of days before current password expires. By default is equals to 90.", alias="passwordExpiration")
    default_policy: Optional[StrictBool] = Field(default=False, description="Defines whether this policy is default or not. Default policy is created automatically when an org is setup. This field is false by default.", alias="defaultPolicy")
    enable_passwd_expiration: Optional[StrictBool] = Field(default=False, description="Defines whether this policy is enabled to expire or not. This field is false by default.", alias="enablePasswdExpiration")
    require_strong_authn: Optional[StrictBool] = Field(default=False, description="Defines whether this policy require strong Auth or not. This field is false by default.", alias="requireStrongAuthn")
    require_strong_auth_off_network: Optional[StrictBool] = Field(default=False, description="Defines whether this policy require strong Auth of network or not. This field is false by default.", alias="requireStrongAuthOffNetwork")
    require_strong_auth_untrusted_geographies: Optional[StrictBool] = Field(default=False, description="Defines whether this policy require strong Auth for untrusted geographies. This field is false by default.", alias="requireStrongAuthUntrustedGeographies")
    use_account_attributes: Optional[StrictBool] = Field(default=False, description="Defines whether this policy uses account attributes or not. This field is false by default.", alias="useAccountAttributes")
    use_dictionary: Optional[StrictBool] = Field(default=False, description="Defines whether this policy uses dictionary or not. This field is false by default.", alias="useDictionary")
    use_identity_attributes: Optional[StrictBool] = Field(default=False, description="Defines whether this policy uses identity attributes or not. This field is false by default.", alias="useIdentityAttributes")
    validate_against_account_id: Optional[StrictBool] = Field(default=False, description="Defines whether this policy validate against account id or not. This field is false by default.", alias="validateAgainstAccountId")
    validate_against_account_name: Optional[StrictBool] = Field(default=False, description="Defines whether this policy validate against account name or not. This field is false by default.", alias="validateAgainstAccountName")
    created: Optional[StrictStr] = None
    modified: Optional[StrictStr] = None
    source_ids: Optional[List[StrictStr]] = Field(default=None, description="List of sources IDs managed by this password policy.", alias="sourceIds")
    __properties: ClassVar[List[str]] = ["id", "description", "name", "dateCreated", "lastUpdated", "firstExpirationReminder", "accountIdMinWordLength", "accountNameMinWordLength", "minAlpha", "minCharacterTypes", "maxLength", "minLength", "maxRepeatedChars", "minLower", "minNumeric", "minSpecial", "minUpper", "passwordExpiration", "defaultPolicy", "enablePasswdExpiration", "requireStrongAuthn", "requireStrongAuthOffNetwork", "requireStrongAuthUntrustedGeographies", "useAccountAttributes", "useDictionary", "useIdentityAttributes", "validateAgainstAccountId", "validateAgainstAccountName", "created", "modified", "sourceIds"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PasswordPolicyV3Dto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if last_updated (nullable) is None
        # and model_fields_set contains the field
        if self.last_updated is None and "last_updated" in self.model_fields_set:
            _dict['lastUpdated'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['modified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of PasswordPolicyV3Dto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "description": obj.get("description"),
            "name": obj.get("name"),
            "dateCreated": obj.get("dateCreated"),
            "lastUpdated": obj.get("lastUpdated"),
            "firstExpirationReminder": obj.get("firstExpirationReminder"),
            "accountIdMinWordLength": obj.get("accountIdMinWordLength"),
            "accountNameMinWordLength": obj.get("accountNameMinWordLength"),
            "minAlpha": obj.get("minAlpha"),
            "minCharacterTypes": obj.get("minCharacterTypes"),
            "maxLength": obj.get("maxLength"),
            "minLength": obj.get("minLength"),
            "maxRepeatedChars": obj.get("maxRepeatedChars"),
            "minLower": obj.get("minLower"),
            "minNumeric": obj.get("minNumeric"),
            "minSpecial": obj.get("minSpecial"),
            "minUpper": obj.get("minUpper"),
            "passwordExpiration": obj.get("passwordExpiration"),
            "defaultPolicy": obj.get("defaultPolicy") if obj.get("defaultPolicy") is not None else False,
            "enablePasswdExpiration": obj.get("enablePasswdExpiration") if obj.get("enablePasswdExpiration") is not None else False,
            "requireStrongAuthn": obj.get("requireStrongAuthn") if obj.get("requireStrongAuthn") is not None else False,
            "requireStrongAuthOffNetwork": obj.get("requireStrongAuthOffNetwork") if obj.get("requireStrongAuthOffNetwork") is not None else False,
            "requireStrongAuthUntrustedGeographies": obj.get("requireStrongAuthUntrustedGeographies") if obj.get("requireStrongAuthUntrustedGeographies") is not None else False,
            "useAccountAttributes": obj.get("useAccountAttributes") if obj.get("useAccountAttributes") is not None else False,
            "useDictionary": obj.get("useDictionary") if obj.get("useDictionary") is not None else False,
            "useIdentityAttributes": obj.get("useIdentityAttributes") if obj.get("useIdentityAttributes") is not None else False,
            "validateAgainstAccountId": obj.get("validateAgainstAccountId") if obj.get("validateAgainstAccountId") is not None else False,
            "validateAgainstAccountName": obj.get("validateAgainstAccountName") if obj.get("validateAgainstAccountName") is not None else False,
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "sourceIds": obj.get("sourceIds")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.identity_profiles_api import IdentityProfilesApi


class TestIdentityProfilesApi(unittest.TestCase):
    """IdentityProfilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityProfilesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_identity_profile(self) -> None:
        """Test case for delete_identity_profile

        Delete an Identity Profile
        """
        pass

    def test_delete_identity_profiles(self) -> None:
        """Test case for delete_identity_profiles

        Delete Identity Profiles
        """
        pass

    def test_export_identity_profiles(self) -> None:
        """Test case for export_identity_profiles

        Export Identity Profiles
        """
        pass

    def test_get_default_identity_attribute_config(self) -> None:
        """Test case for get_default_identity_attribute_config

        Get default Identity Attribute Config
        """
        pass

    def test_get_identity_profile(self) -> None:
        """Test case for get_identity_profile

        Get single Identity Profile
        """
        pass

    def test_import_identity_profiles(self) -> None:
        """Test case for import_identity_profiles

        Import Identity Profiles
        """
        pass

    def test_list_identity_profiles(self) -> None:
        """Test case for list_identity_profiles

        Identity Profiles List
        """
        pass

    def test_sync_identity_profile(self) -> None:
        """Test case for sync_identity_profile

        Process identities under profile
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.connectors_api import ConnectorsApi


class TestConnectorsApi(unittest.TestCase):
    """ConnectorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConnectorsApi()

    def tearDown(self) -> None:
        pass

    def test_get_connector_list(self) -> None:
        """Test case for get_connector_list

        Gets connector list
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from sailpoint.v3.models.completed_approval import CompletedApproval

class TestCompletedApproval(unittest.TestCase):
    """CompletedApproval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CompletedApproval:
        """Test CompletedApproval
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CompletedApproval`
        """
        model = CompletedApproval()
        if include_optional:
            return CompletedApproval(
                id = 'id12345',
                name = 'aName',
                created = '2017-07-11T18:45:37.098Z',
                modified = '2018-07-25T20:22:28.104Z',
                request_created = '2017-07-11T18:45:35.098Z',
                request_type = 'GRANT_ACCESS',
                requester = sailpoint.v3.models.access_item_requester.AccessItemRequester(
                    type = 'IDENTITY', 
                    id = '2c7180a46faadee4016fb4e018c20648', 
                    name = 'William Wilson', ),
                requested_for = [
                    sailpoint.v3.models.access_item_requested_for.AccessItemRequestedFor(
                        type = 'IDENTITY', 
                        id = '2c4180a46faadee4016fb4e018c20626', 
                        name = 'Robert Robinson', )
                    ],
                reviewed_by = sailpoint.v3.models.access_item_reviewed_by.AccessItemReviewedBy(
                    type = 'IDENTITY', 
                    id = '2c3780a46faadee4016fb4e018c20652', 
                    name = 'Allen Albertson', ),
                owner = sailpoint.v3.models.owner_dto.OwnerDto(
                    type = 'IDENTITY', 
                    id = '2c9180a46faadee4016fb4e018c20639', 
                    name = 'Support', ),
                requested_object = sailpoint.v3.models.requestable_object_reference.RequestableObjectReference(
                    id = '2c9180835d2e5168015d32f890ca1581', 
                    name = 'Applied Research Access', 
                    description = 'Access to research information, lab results, and schematics', 
                    type = 'ROLE', ),
                requester_comment = None,
                reviewer_comment = None,
                previous_reviewers_comments = [
                    sailpoint.v3.models.comment_dto.CommentDto(
                        comment = 'This is a comment.', 
                        created = '2017-07-11T18:45:37.098Z', 
                        author = sailpoint.v3.models.comment_dto_author.CommentDto_author(
                            type = 'IDENTITY', 
                            id = '2c9180847e25f377017e2ae8cae4650b', 
                            name = 'john.doe', ), )
                    ],
                forward_history = [
                    sailpoint.v3.models.approval_forward_history.ApprovalForwardHistory(
                        old_approver_name = 'Frank Mir', 
                        new_approver_name = 'Al Volta', 
                        comment = 'Forwarding from Frank to Al', 
                        modified = '2019-08-23T18:52:57.398Z', 
                        forwarder_name = 'William Wilson', 
                        reassignment_type = 'AUTOMATIC_REASSIGNMENT', )
                    ],
                comment_required_when_rejected = True,
                state = 'APPROVED',
                remove_date = '2020-07-11T00:00Z',
                remove_date_update_requested = True,
                current_remove_date = '2020-07-11T00:00Z',
                sod_violation_context = sailpoint.v3.models.sod_violation_context_check_completed.SodViolationContextCheckCompleted(
                    state = 'SUCCESS', 
                    uuid = 'f73d16e9-a038-46c5-b217-1246e15fdbdd', 
                    violation_check_result = sailpoint.v3.models.sod_violation_check_result.SodViolationCheckResult(
                        message = sailpoint.v3.models.error_message_dto.ErrorMessageDto(
                            locale = 'en-US', 
                            locale_origin = 'DEFAULT', 
                            text = 'The request was syntactically correct but its content is semantically invalid.', ), 
                        client_metadata = {requestedAppName=test-app, requestedAppId=2c91808f7892918f0178b78da4a305a1}, 
                        violation_contexts = [
                            sailpoint.v3.models.sod_violation_context.SodViolationContext(
                                policy = sailpoint.v3.models.sod_policy_dto.SodPolicyDto(
                                    type = 'SOD_POLICY', 
                                    id = '0f11f2a4-7c94-4bf3-a2bd-742580fe3bde', 
                                    name = 'Business SOD Policy', ), 
                                conflicting_access_criteria = sailpoint.v3.models.sod_violation_context_conflicting_access_criteria.SodViolationContext_conflictingAccessCriteria(
                                    left_criteria = sailpoint.v3.models.sod_violation_context_conflicting_access_criteria_left_criteria.SodViolationContext_conflictingAccessCriteria_leftCriteria(
                                        criteria_list = [
                                            sailpoint.v3.models.sod_exempt_criteria.SodExemptCriteria(
                                                existing = True, 
                                                type = 'IDENTITY', 
                                                id = '2c918085771e9d3301773b3cb66f6398', 
                                                name = 'My HR Entitlement', )
                                            ], ), 
                                    right_criteria = sailpoint.v3.models.sod_violation_context_conflicting_access_criteria_left_criteria.SodViolationContext_conflictingAccessCriteria_leftCriteria(), ), )
                            ], 
                        violated_policies = [
                            sailpoint.v3.models.sod_policy_dto.SodPolicyDto(
                                id = '0f11f2a4-7c94-4bf3-a2bd-742580fe3bde', 
                                name = 'Business SOD Policy', )
                            ], ), ),
                pre_approval_trigger_result = sailpoint.v3.models.completed_approval_pre_approval_trigger_result.CompletedApproval_preApprovalTriggerResult(
                    comment = 'This request was autoapproved by our automated ETS subscriber', 
                    decision = 'APPROVED', 
                    reviewer = 'Automated AR Approval', 
                    date = '2022-06-07T19:18:40.748Z', ),
                client_metadata = {requestedAppName=test-app, requestedAppId=2c91808f7892918f0178b78da4a305a1},
                requested_accounts = ''
            )
        else:
            return CompletedApproval(
        )
        """

    def testCompletedApproval(self):
        """Test CompletedApproval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.beta.models.form_condition import FormCondition
from sailpoint.beta.models.form_definition_input import FormDefinitionInput
from sailpoint.beta.models.form_element import FormElement
from sailpoint.beta.models.form_owner import FormOwner
from sailpoint.beta.models.form_used_by import FormUsedBy
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class FormDefinitionResponse(BaseModel):
    """
    FormDefinitionResponse
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Unique guid identifying the form definition.")
    name: Optional[StrictStr] = Field(default=None, description="Name of the form definition.")
    description: Optional[StrictStr] = Field(default=None, description="Form definition's description.")
    owner: Optional[FormOwner] = None
    used_by: Optional[List[FormUsedBy]] = Field(default=None, description="List of objects using the form definition. Whenever a system uses a form, the API reaches out to the form service to record that the system is currently using it.", alias="usedBy")
    form_input: Optional[List[FormDefinitionInput]] = Field(default=None, description="List of form inputs required to create a form-instance object.", alias="formInput")
    form_elements: Optional[List[FormElement]] = Field(default=None, description="List of nested form elements.", alias="formElements")
    form_conditions: Optional[List[FormCondition]] = Field(default=None, description="Conditional logic that can dynamically modify the form as the recipient is interacting with it.", alias="formConditions")
    created: Optional[datetime] = Field(default=None, description="Created is the date the form definition was created")
    modified: Optional[datetime] = Field(default=None, description="Modified is the last date the form definition was modified")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "owner", "usedBy", "formInput", "formElements", "formConditions", "created", "modified"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FormDefinitionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in used_by (list)
        _items = []
        if self.used_by:
            for _item in self.used_by:
                if _item:
                    _items.append(_item.to_dict())
            _dict['usedBy'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_input (list)
        _items = []
        if self.form_input:
            for _item in self.form_input:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formInput'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_elements (list)
        _items = []
        if self.form_elements:
            for _item in self.form_elements:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formElements'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_conditions (list)
        _items = []
        if self.form_conditions:
            for _item in self.form_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formConditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of FormDefinitionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "owner": FormOwner.from_dict(obj.get("owner")) if obj.get("owner") is not None else None,
            "usedBy": [FormUsedBy.from_dict(_item) for _item in obj.get("usedBy")] if obj.get("usedBy") is not None else None,
            "formInput": [FormDefinitionInput.from_dict(_item) for _item in obj.get("formInput")] if obj.get("formInput") is not None else None,
            "formElements": [FormElement.from_dict(_item) for _item in obj.get("formElements")] if obj.get("formElements") is not None else None,
            "formConditions": [FormCondition.from_dict(_item) for _item in obj.get("formConditions")] if obj.get("formConditions") is not None else None,
            "created": obj.get("created"),
            "modified": obj.get("modified")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.auth_users_api import AuthUsersApi


class TestAuthUsersApi(unittest.TestCase):
    """AuthUsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthUsersApi()

    def tearDown(self) -> None:
        pass

    def test_get_auth_user(self) -> None:
        """Test case for get_auth_user

        Auth User Details
        """
        pass

    def test_patch_auth_user(self) -> None:
        """Test case for patch_auth_user

        Auth User Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

from setuptools import setup, find_packages  # noqa: H301

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "sailpoint"
VERSION = "1.0.6"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0", "python-dateutil", "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="The SailPoint API SDK for Python",
    author="SailPoint Developer Relations",
    author_email="developer-relations@sailpoint.com",
    url="https://developer.sailpoint.com/",
    keywords=["OpenAPI", "OpenAPI-Generator", "SailPoint", "SDK"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description=long_description,
    package_data={"sailpoint": ["py.typed"]},
    classifiers=[
        "Development Status :: 4 - Beta",

        "Intended Audience :: Developers",

        "License :: OSI Approved :: MIT License",

        "Operating System :: OS Independent",

        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    project_urls={
        "Documentation": "https://developer.sailpoint.com/idn/tools/sdk/python",
        "Issues": "https://github.com/sailpoint-oss/python-sdk/issues"
    }
)



# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.v3.models.document_type import DocumentType
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Event(BaseModel):
    """
    Event
    """ # noqa: E501
    id: StrictStr
    name: StrictStr
    type: DocumentType = Field(alias="_type")
    created: Optional[datetime] = Field(default=None, description="ISO-8601 date-time referring to the time when the object was created.")
    synced: Optional[StrictStr] = Field(default=None, description="ISO-8601 date-time referring to the date-time when object was queued to be synced into search database for use in the search API.   This date-time changes anytime there is an update to the object, which triggers a synchronization event being sent to the search database.  There may be some delay between the `synced` time and the time when the updated data is actually available in the search API. ")
    action: Optional[StrictStr] = Field(default=None, description="Name of the event as it's displayed in audit reports.")
    type: Optional[StrictStr] = Field(default=None, description="Event type. Refer to [Event Types](https://documentation.sailpoint.com/saas/help/search/index.html#event-types) for a list of event types and their meanings.")
    actor: Optional[StrictStr] = Field(default=None, description="Name of the actor that generated the event.")
    target: Optional[StrictStr] = Field(default=None, description="Name of the target, or recipient, of the event.")
    stack: Optional[StrictStr] = Field(default=None, description="The event's stack.")
    tracking_number: Optional[StrictStr] = Field(default=None, description="ID of the group of events.", alias="trackingNumber")
    ip_address: Optional[StrictStr] = Field(default=None, description="Target system's IP address.", alias="ipAddress")
    details: Optional[StrictStr] = Field(default=None, description="ID of event's details.")
    attributes: Optional[Dict[str, Any]] = Field(default=None, description="Attributes involved in the event.")
    objects: Optional[List[StrictStr]] = Field(default=None, description="Objects the event is happening to.")
    operation: Optional[StrictStr] = Field(default=None, description="Operation, or action, performed during the event.")
    status: Optional[StrictStr] = Field(default=None, description="Event status. Refer to [Event Statuses](https://documentation.sailpoint.com/saas/help/search/index.html#event-statuses) for a list of event statuses and their meanings.")
    technical_name: Optional[StrictStr] = Field(default=None, description="Event's normalized name. This normalized name always follows the pattern of 'objects_operation_status'.", alias="technicalName")
    __properties: ClassVar[List[str]] = ["id", "name", "_type", "created", "synced", "action", "type", "actor", "target", "stack", "trackingNumber", "ipAddress", "details", "attributes", "objects", "operation", "status", "technicalName"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Event from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Event from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "_type": obj.get("_type"),
            "created": obj.get("created"),
            "synced": obj.get("synced"),
            "action": obj.get("action"),
            "type": obj.get("type"),
            "actor": obj.get("actor"),
            "target": obj.get("target"),
            "stack": obj.get("stack"),
            "trackingNumber": obj.get("trackingNumber"),
            "ipAddress": obj.get("ipAddress"),
            "details": obj.get("details"),
            "attributes": obj.get("attributes"),
            "objects": obj.get("objects"),
            "operation": obj.get("operation"),
            "status": obj.get("status"),
            "technicalName": obj.get("technicalName")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, field_validator
from pydantic import Field
from sailpoint.beta.models.form_instance_created_by import FormInstanceCreatedBy
from sailpoint.beta.models.form_instance_recipient import FormInstanceRecipient
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class CreateFormInstanceRequest(BaseModel):
    """
    CreateFormInstanceRequest
    """ # noqa: E501
    created_by: FormInstanceCreatedBy = Field(alias="createdBy")
    expire: StrictStr = Field(description="Expire is required")
    form_definition_id: StrictStr = Field(description="FormDefinitionID is the id of the form definition that created this form", alias="formDefinitionId")
    form_input: Optional[Dict[str, Any]] = Field(default=None, description="FormInput is an object of form input labels to value", alias="formInput")
    recipients: List[FormInstanceRecipient] = Field(description="Recipients is required")
    stand_alone_form: Optional[StrictBool] = Field(default=False, description="StandAloneForm is a boolean flag to indicate if this form should be available for users to complete via the standalone form UI or should this only be available to be completed by as an embedded form", alias="standAloneForm")
    state: Optional[StrictStr] = Field(default=None, description="State is required, if not present initial state is FormInstanceStateAssigned ASSIGNED FormInstanceStateAssigned IN_PROGRESS FormInstanceStateInProgress SUBMITTED FormInstanceStateSubmitted COMPLETED FormInstanceStateCompleted CANCELLED FormInstanceStateCancelled")
    ttl: Optional[StrictInt] = Field(default=None, description="TTL an epoch timestamp in seconds, it most be in seconds or dynamodb will ignore it SEE: https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/time-to-live-ttl-before-you-start.html")
    __properties: ClassVar[List[str]] = ["createdBy", "expire", "formDefinitionId", "formInput", "recipients", "standAloneForm", "state", "ttl"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('ASSIGNED', 'IN_PROGRESS', 'SUBMITTED', 'COMPLETED', 'CANCELLED'):
            raise ValueError("must be one of enum values ('ASSIGNED', 'IN_PROGRESS', 'SUBMITTED', 'COMPLETED', 'CANCELLED')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CreateFormInstanceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in recipients (list)
        _items = []
        if self.recipients:
            for _item in self.recipients:
                if _item:
                    _items.append(_item.to_dict())
            _dict['recipients'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of CreateFormInstanceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdBy": FormInstanceCreatedBy.from_dict(obj.get("createdBy")) if obj.get("createdBy") is not None else None,
            "expire": obj.get("expire"),
            "formDefinitionId": obj.get("formDefinitionId"),
            "formInput": obj.get("formInput"),
            "recipients": [FormInstanceRecipient.from_dict(_item) for _item in obj.get("recipients")] if obj.get("recipients") is not None else None,
            "standAloneForm": obj.get("standAloneForm") if obj.get("standAloneForm") is not None else False,
            "state": obj.get("state"),
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from pydantic import StrictBytes, StrictStr

from typing import List, Optional, Union

from sailpoint.beta.models.discovered_applications_inner import DiscoveredApplicationsInner
from sailpoint.beta.models.manual_discover_applications_template import ManualDiscoverApplicationsTemplate
from sailpoint.beta.models.vendor_connector_mapping import VendorConnectorMapping

from sailpoint.beta.api_client import ApiClient
from sailpoint.beta.api_response import ApiResponse
from sailpoint.beta.rest import RESTResponseType


class ApplicationDiscoveryApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_discovered_applications(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filter: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* ")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[List[DiscoveredApplicationsInner]]:
        """Retrieve discovered applications for tenant

        Fetches a list of applications that have been identified within the environment. This includes details such as application names, discovery dates, potential correlated saas_vendors and related suggested connectors. 

        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param filter: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* 
        :type filter: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_discovered_applications_serialize(
            limit=limit,
            offset=offset,
            filter=filter,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[List[DiscoveredApplicationsInner]]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_discovered_applications_with_http_info(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filter: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* ")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[List[DiscoveredApplicationsInner]]]:
        """Retrieve discovered applications for tenant

        Fetches a list of applications that have been identified within the environment. This includes details such as application names, discovery dates, potential correlated saas_vendors and related suggested connectors. 

        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param filter: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* 
        :type filter: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_discovered_applications_serialize(
            limit=limit,
            offset=offset,
            filter=filter,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[List[DiscoveredApplicationsInner]]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_discovered_applications_without_preload_content(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filter: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* ")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve discovered applications for tenant

        Fetches a list of applications that have been identified within the environment. This includes details such as application names, discovery dates, potential correlated saas_vendors and related suggested connectors. 

        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param filter: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)       Filtering is supported for the following fields and operators:  **name**: *eq, sw, co*  **description**: *eq, sw, co* 
        :type filter: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **name, description, discoveredAt, discoverySource**
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_discovered_applications_serialize(
            limit=limit,
            offset=offset,
            filter=filter,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[List[DiscoveredApplicationsInner]]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_discovered_applications_serialize(
        self,
        limit,
        offset,
        filter,
        sorters,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if filter is not None:
            
            _query_params.append(('filter', filter))
            
        if sorters is not None:
            
            _query_params.append(('sorters', sorters))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'UserContextAuth', 
            'UserContextAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/discovered-applications',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_manual_discover_applications_csv_template(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManualDiscoverApplicationsTemplate:
        """CSV template download for discovery

        This endpoint allows the user to download an example CSV file with two columns `application_name` and `description`.  The CSV file contains a single row with the values 'Example Application' and 'Example Description'.  The downloaded template is specifically designed for use with the `/manual-discover-applications` endpoint. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_manual_discover_applications_csv_template_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ManualDiscoverApplicationsTemplate",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_manual_discover_applications_csv_template_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManualDiscoverApplicationsTemplate]:
        """CSV template download for discovery

        This endpoint allows the user to download an example CSV file with two columns `application_name` and `description`.  The CSV file contains a single row with the values 'Example Application' and 'Example Description'.  The downloaded template is specifically designed for use with the `/manual-discover-applications` endpoint. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_manual_discover_applications_csv_template_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ManualDiscoverApplicationsTemplate",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_manual_discover_applications_csv_template_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """CSV template download for discovery

        This endpoint allows the user to download an example CSV file with two columns `application_name` and `description`.  The CSV file contains a single row with the values 'Example Application' and 'Example Description'.  The downloaded template is specifically designed for use with the `/manual-discover-applications` endpoint. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_manual_discover_applications_csv_template_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ManualDiscoverApplicationsTemplate",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_manual_discover_applications_csv_template_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'text/csv', 
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'UserContextAuth', 
            'UserContextAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/manual-discover-applications-template',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_vendor_connector_mappings(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[VendorConnectorMapping]:
        """List vendor connector mappings

        Retrieves a list of mappings between SaaS vendors and IDN connectors, detailing the connections established for correlation. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_vendor_connector_mappings_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VendorConnectorMapping]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '405': "CreateDomainDkim405Response",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_vendor_connector_mappings_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[VendorConnectorMapping]]:
        """List vendor connector mappings

        Retrieves a list of mappings between SaaS vendors and IDN connectors, detailing the connections established for correlation. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_vendor_connector_mappings_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VendorConnectorMapping]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '405': "CreateDomainDkim405Response",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_vendor_connector_mappings_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List vendor connector mappings

        Retrieves a list of mappings between SaaS vendors and IDN connectors, detailing the connections established for correlation. 

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_vendor_connector_mappings_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VendorConnectorMapping]",
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '405': "CreateDomainDkim405Response",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_vendor_connector_mappings_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'UserContextAuth', 
            'UserContextAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/vendor-connector-mappings',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def send_manual_discover_applications_csv_template(
        self,
        file: Annotated[Union[StrictBytes, StrictStr], Field(description="The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """CSV Upload to discover applications

        This endpoint supports uploading a CSV file with application data for manual correlation to specific IDN connectors.  If a suitable IDN connector is unavailable, the system will recommend generic connectors instead.

        :param file: The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered. (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_manual_discover_applications_csv_template_serialize(
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def send_manual_discover_applications_csv_template_with_http_info(
        self,
        file: Annotated[Union[StrictBytes, StrictStr], Field(description="The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """CSV Upload to discover applications

        This endpoint supports uploading a CSV file with application data for manual correlation to specific IDN connectors.  If a suitable IDN connector is unavailable, the system will recommend generic connectors instead.

        :param file: The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered. (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_manual_discover_applications_csv_template_serialize(
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def send_manual_discover_applications_csv_template_without_preload_content(
        self,
        file: Annotated[Union[StrictBytes, StrictStr], Field(description="The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """CSV Upload to discover applications

        This endpoint supports uploading a CSV file with application data for manual correlation to specific IDN connectors.  If a suitable IDN connector is unavailable, the system will recommend generic connectors instead.

        :param file: The CSV file to upload containing `application_name` and `description` columns. Each row represents an application to be discovered. (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._send_manual_discover_applications_csv_template_serialize(
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponseDto",
            '401': "ListAccessModelMetadataAttribute401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessModelMetadataAttribute429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _send_manual_discover_applications_csv_template_serialize(
        self,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'UserContextAuth', 
            'UserContextAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/manual-discover-applications',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.identity_profiles_api import IdentityProfilesApi


class TestIdentityProfilesApi(unittest.TestCase):
    """IdentityProfilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityProfilesApi()

    def tearDown(self) -> None:
        pass

    def test_create_identity_profile(self) -> None:
        """Test case for create_identity_profile

        Create an Identity Profile
        """
        pass

    def test_delete_identity_profile(self) -> None:
        """Test case for delete_identity_profile

        Delete an Identity Profile
        """
        pass

    def test_delete_identity_profiles(self) -> None:
        """Test case for delete_identity_profiles

        Delete Identity Profiles
        """
        pass

    def test_export_identity_profiles(self) -> None:
        """Test case for export_identity_profiles

        Export Identity Profiles
        """
        pass

    def test_generate_identity_preview(self) -> None:
        """Test case for generate_identity_preview

        Generate Identity Profile Preview
        """
        pass

    def test_get_default_identity_attribute_config(self) -> None:
        """Test case for get_default_identity_attribute_config

        Default identity attribute config
        """
        pass

    def test_get_identity_profile(self) -> None:
        """Test case for get_identity_profile

        Gets a single Identity Profile
        """
        pass

    def test_import_identity_profiles(self) -> None:
        """Test case for import_identity_profiles

        Import Identity Profiles
        """
        pass

    def test_list_identity_profiles(self) -> None:
        """Test case for list_identity_profiles

        Identity Profiles list
        """
        pass

    def test_sync_identity_profile(self) -> None:
        """Test case for sync_identity_profile

        Process identities under profile
        """
        pass

    def test_update_identity_profile(self) -> None:
        """Test case for update_identity_profile

        Update the Identity Profile
        """
        pass


if __name__ == '__main__':
    unittest.main()
